import { StoreConsumer } from "../index";
import * as React from "react";
/**
 * Attaches parts of the store to the Component via a mapStoreToProps function. Should return at least an empty
 * Object
 * TODO: Change Component type to React.ComponentClass<any, any> causes errors on getDerivedStateFromProps
 * @param attachParts MapStoreToPros function
 */
function AttachPartsOfStore(attachParts) {
    return (Component) => {
        // Since the Components should have props that are not added via this function
        // We have to use any as generic in this sfc.
        const AttachedStore = (props) => {
            return (React.createElement(StoreConsumer, null, (store) => {
                const attachedParts = attachParts(store);
                return React.createElement(Component, Object.assign({}, props, attachedParts, { store: store }));
            }));
        };
        return AttachedStore;
    };
}
export { AttachPartsOfStore };
//# sourceMappingURL=AttachPartsOfStore.js.map